"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
}
Object.defineProperty(exports, "__esModule", { value: true });
const v4_1 = __importDefault(require("uuid/v4"));
const ocean_api_1 = require("./ocean-api");
const request_1 = __importDefault(require("./request"));
exports.C_ClientID = 'QMOC_clientId';
exports.C_SessionID = 'QMOC_sessionId';
const C_30m = 30 * 60; //sessionId缓存时间 30分钟
const C_20Y = 20 * 365 * 24 * 60 * 60; //clientID缓存时间 20年
class OceanInstance {
    constructor(fetch, systemInfo, envInfo, storage, beforeSend) {
        this.fetch = fetch;
        this.envInfo = envInfo;
        this.storage = storage;
        this.systemInfo = systemInfo;
        this.beforeSend = beforeSend;
        this.oceanApi = ocean_api_1.getOceanApi(fetch, this.systemInfo);
    }
    setQmId(qmid) {
        if (!this.envInfo.qmId) {
            this.envInfo.qmId = qmid;
        }
        else if (this.envInfo.qmId !== qmid) {
            this.envInfo.qmId = qmid;
            this.storage.remove(exports.C_SessionID).then(() => { });
        }
    }
    setShopId(shopId) {
        this.envInfo.shopId = shopId;
    }
    /**
     * 如果缓存中有clientID则直接从clientID中拿,
     * 如果缓存中没有clientID则生成 且保存在缓存中,过期时间 the long the better;
     * @returns {string}
     */
    getClientId() {
        if (this._clientID) {
            return Promise.resolve(this._clientID);
        }
        else {
            return this.getAndUpdate(exports.C_ClientID, C_20Y);
        }
    }
    /**
     * 如果缓存中有sessionId则直接从sessionId中拿;
     * 如果缓存中没有sessionId则生成;
     * session的时间控制交好缓存的过期机制来保证;
     * 每次使用都要更新下过期时间;
     * @returns {string}
     */
    getSessionId() {
        return this.getAndUpdate(exports.C_SessionID, C_30m);
    }
    /**
     *
     * @returns {Promise<string>}
     */
    getAndUpdate(key, timeout) {
        return new Promise((resolve, reject) => {
            this.storage.get(key).then(val => {
                if (!val) {
                    val = v4_1.default();
                }
                //更新下缓存的时间 不需要同步来做
                this.storage.save(key, val, timeout).then(() => { });
                resolve(val);
            }, reject);
        });
    }
    /**
     * 发布浏览记录请求;
     * @param {IViewRequest | IGoodsViewRequest} request
     */
    sendView(request, context) {
        Promise.all([
            this.getSessionId(),
            this.getClientId(),
        ]).then(([sessionId, clientId]) => {
            let oceanRequest = new request_1.default(Object.assign({}, request, this.envInfo, {
                sessionId,
                clientId,
            }), context);
            if (this.beforeSend) {
                this.beforeSend(oceanRequest, this._send.bind(this, oceanRequest));
            }
            else {
                this._send(oceanRequest).then(() => { }, () => { });
            }
        });
    }
    _send(oceanRequest) {
        return new Promise((resolve, reject) => {
            this.oceanApi(oceanRequest.toJSON()).then(resolve, reject);
        });
    }
}
exports.OceanInstance = OceanInstance;
