import OceanRequest from './request';
export interface IFetch {
    (url: string, params: {
        method: string;
        headers: {
            'X-OC-KEY': string;
            'X-OC-SECRET': string;
            'Content-Type': string;
        };
        body: string;
    }): {};
}
/**
 * 平台类型
 */
export declare enum EPlatform {
    /**
     * PC浏览器
     */
    PC = 1,
    /**
     * 微信
     */
    WEIXIN = 2,
    /**
     * APP
     */
    APP = 3,
    /**
     * H5
     */
    H5 = 4,
    /**
     * 小程序
     */
    MINI = 5,
}
export interface IStorage {
    save(key: string, value: string, timeout: number): Promise<void>;
    get(key: string): Promise<string>;
    remove(key: string): Promise<void>;
}
export interface IInnerState {
    /**
     * 客户端session ID，会超时
     */
    sessionId?: string;
    clientId?: string;
}
/**
 * 系统信息,
 */
export interface ISystemInfo {
    /**
     * 系统标识，由Ocean生成， 一个业务系统对应一个key，不可更改
     */
    key: string;
    /**
     * 密钥，由Ocean生成，可重置
     */
    secret: string;
}
export interface IEnvInfo {
    /**
     * 网站host，必填
     */
    host: string;
    /**
     * 来源Page
     */
    source?: string;
    /**
     * 用户千米ID
     */
    qmId?: string;
    /**
     * 店铺ID
     */
    shopId: string;
    /**
     * client type，必填
     */
    clientType: EPlatform;
}
/**
 * 浏览记录请求
 */
export interface IView {
    /**
     * 网址url，必填
     */
    url: string;
    attrs?: {
        skuId?: string;
        spuId?: string;
    };
    /**
     * 时间戳，毫秒值，不填的话取服务器当前时间
     */
    timestamp?: number;
}
export interface IContext {
    auto?: boolean;
    location?: {
        hash: string;
        host: string;
        hostname: string;
        pathname: string;
        search: string;
    };
}
export interface IViewRequest extends IView, IEnvInfo, IInnerState {
}
export interface IOceanApi {
    (request: IViewRequest): Promise<void>;
}
export interface IFetch {
    (url: string, data: {
        method: string;
        headers: {
            [name: string]: string;
        };
        body: string;
    }): Promise<any>;
}
export interface IBeforeSend {
    (oceanRequest: OceanRequest, next: any): void;
}
export interface IOceanClientOption {
    beforeSend?: IBeforeSend;
}
